## $Id: viewlets.py 17388 2023-04-20 09:41:19Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from waeup.kofa.interfaces import REQUESTED
from waeup.kofa.browser.viewlets import ManageActionButton
from kofacustom.edocons.students.interfaces import (
    ICustomStudentStudyCourse, ICustomStudentStudyLevel)
from waeup.kofa.students.fileviewlets import (
    StudentFileDisplay, StudentFileUpload, StudentImage)
from waeup.kofa.students.browser import (
    ExportPDFClearanceSlip, StudyCourseDisplayFormPage,
    StudyLevelDisplayFormPage)
from waeup.kofa.students.viewlets import (
    AddPreviousPaymentActionButton, AddBalancePaymentActionButton,
    StudentPersonalEditActionButton)

from kofacustom.nigeria.interfaces import MessageFactory as _

class AddBalancePaymentActionButton(AddBalancePaymentActionButton):
    grok.require('waeup.manageStudent')

# Medical Certificate

class MedicalCertificateDisplay(StudentFileDisplay):
    """Medical Certificate display viewlet.
    """
    grok.order(19)
    label = _(u'Medical Certificate')
    title = _(u'Medical Certificate')
    download_name = u'medcert'

class MedicalCertificateSlip(MedicalCertificateDisplay):
    grok.view(ExportPDFClearanceSlip)

class MedicalCertificateUpload(StudentFileUpload):
    """Medical Certificate upload viewlet.
    """
    grok.order(19)
    label = _(u'Medical Certificate (attach blood group, genotype and chest X-ray in one pdf file)')
    title = _(u'Medical Certificate Scan')
    download_name = u'medcert'

class MedicalCertificateImage(StudentImage):
    """Renders Medical Certificate scan.
    """
    grok.name('medcert')
    download_name = u'medcert'

# Specification for Female Uniform 

class SpecificationFemaleUniformDisplay(StudentFileDisplay):
    """Specification for Female Uniform display viewlet.
    """
    grok.order(20)
    label = _(u'Specification for Female Uniform')
    title = _(u'Specification for Female Uniform')
    download_name = u'femuniform'

class SpecificationFemaleUniformSlip(SpecificationFemaleUniformDisplay):
    grok.view(ExportPDFClearanceSlip)

class SpecificationFemaleUniformUpload(StudentFileUpload):
    """Specification for Female Uniform upload viewlet.
    """
    grok.order(20)
    label = _(u'Specification for Female Uniform')
    title = _(u'Specification for Female Uniform')
    download_name = u'femuniform'

class SpecificationFemaleUniformImage(StudentImage):
    """Renders Medical Certificate scan.
    """
    grok.name('femuniform')
    download_name = u'femuniform'
    
# Hostel Form

class HostelFormDisplay(StudentFileDisplay):
    """Hostel Form display viewlet.
    """
    grok.order(21)
    label = _(u'Hostel Form')
    title = _(u'Hostel Form')
    download_name = u'hostel'

class HostelFormSlip(HostelFormDisplay):
    grok.view(ExportPDFClearanceSlip)

class HostelFormUpload(StudentFileUpload):
    """Hostel Form upload viewlet.
    """
    grok.order(22)
    label = _(u'Hostel Form (for those in hostel only)')
    title = _(u'Hostel Form Scan')
    download_name = u'hostel'

class HostelFormImage(StudentImage):
    """Renders Hostel Form scan.
    """
    grok.name('hostel')
    download_name = u'hostel'


# Renouncement of Cult

class RenouncementCultDisplay(StudentFileDisplay):
    """Renouncement of Cult display viewlet.
    """
    grok.order(23)
    label = _(u'Renouncement of Cult')
    title = _(u'Renouncement of Cult')
    download_name = u'cult'

class RenouncementCultSlip(RenouncementCultDisplay):
    grok.view(ExportPDFClearanceSlip)

class RenouncementCultUpload(StudentFileUpload):
    """Renouncement of Cult upload viewlet.
    """
    grok.order(23)
    label = _(u'Renouncement of Cult')
    title = _(u'Renouncement of Cult Scan')
    download_name = u'cult'

class RenouncementCultImage(StudentImage):
    """Renders Renouncement of Cult scan.
    """
    grok.name('cult')
    download_name = u'cult'


# Letter of Sponsorship

class LetterSponsorshipDisplay(StudentFileDisplay):
    """Letter of Sponsorship display viewlet.
    """
    grok.order(24)
    label = _(u'Letter of Sponsorship')
    title = _(u'Letter of Sponsorship')
    download_name = u'sponsor'

class LetterSponsorshipSlip(LetterSponsorshipDisplay):
    grok.view(ExportPDFClearanceSlip)

class LetterSponsorshipUpload(StudentFileUpload):
    """Letter of Sponsorship upload viewlet.
    """
    grok.order(24)
    label = _(u'Letter of Sponsorship')
    title = _(u'Letter of Sponsorship Scan')
    download_name = u'sponsor'

class LetterSponsorshipImage(StudentImage):
    """Renders Letter of Sponsorship scan.
    """
    grok.name('sponsor')
    download_name = u'sponsor'
